NLSL: i4_datum Union Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Data Types List
- Data Types
- Data Fields

Public Attributes | List of all members
i4_datum Union Reference

## Public Attributes
long int | number
unsigned int | word [2]

## Detailed Description

Definition at line 77 of file genio.c.

## Member Data Documentation

long int i4_datum::number

Definition at line 78 of file genio.c.

unsigned int i4_datum::word[2]

Definition at line 79 of file genio.c.

The documentation for this union was generated from the following file:

- genio.c